function monitorscan
% OPENSPEC Called by specr to load fids of scans in a selected spec file
%
% Copyright 2005, Zhang Jiang

hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarMonitor = findall(hFigSpecr,'Tag','toolbarMonitor');
hTimerMonitor   = timerfindall('Tag','timerMonitor');

% --- get setttings
settings = getappdata(hFigSpecr,'settings');
file = settings.file;
scan = settings.scan;

% --- get initial 'enable' property of menus,toolbars and pushbuttons 
hEnableGroup  = [...
    findall(hFigSpecr,'Tag','specr_MenuTools');...
    findall(hFigSpecr,'Tag','specr_MenuFile');...
    findall(hFigSpecr,'Tag','toolbarOpen');...
    findall(hFigSpecr,'Tag','toolbarSave');...
    findall(hFigSpecr,'Tag','toolbarPrint');...
    findall(hFigSpecr,'Tag','toolbarEditPlot');...
    findall(hFigSpecr,'Tag','toolbarZoom');...
    findall(hFigSpecr,'Tag','toolbarDataCursor');...
    findall(hFigSpecr,'Tag','toolbarLegend');...
    findall(hFigSpecr,'Tag','toolbarPlottoolsOff');...
    findall(hFigSpecr,'Tag','toolbarPlottoolsOn');...
    findall(hFigSpecr,'Tag','toolbarInvert');...
    findall(hFigSpecr,'Tag','toolbarMerge');...
    findall(hFigSpecr,'Tag','toolbarConvert');...
    findall(hFigSpecr,'Tag','toolbarFootprint');...
    findall(hFigSpecr,'Tag','specr_PushbuttonSelectScan');...
    ];
initEnable = get(hEnableGroup,'Enable');

if isempty(file) | isempty(scan.fidPos)
    set(hToolbarMonitor,'state','off');
    return;    
end

icons = load('icons.mat');
if strcmp(get(hToolbarMonitor,'state'),'on');
    set(hToolbarMonitor,'CData',icons.iconmonitor.pause);
else
    set(hToolbarMonitor,'CData',icons.iconmonitor.play);
    if ~isempty(hTimerMonitor)
        if isvalid(hTimerMonitor)
            stop(hTimerMonitor);
        end
        delete(hTimerMonitor);
    end
    return;
end

% --- set and start timer
hTimerMonitor=timer('Tag','timerMonitor');
set(hTimerMonitor,'StartDelay', 1,...
    'TimerFcn', @timerMonitorFcn,...
    'StartFcn', {@timerMonitorStartFcn,hEnableGroup,initEnable},...
    'StopFcn',  {@timerMonitorStopFcn,hEnableGroup,initEnable},...
    'ExecutionMode','fixedRate',...
    'BusyMode','drop',...
    'TasksToExecute',inf,...
    'Period',settings.monitorPeriod);
start(hTimerMonitor);


%================================================================
% --- callback function of monitor timer
%================================================================
function timerMonitorFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hTimerMonitor   = timerfind('Tag','timerMonitor');
hPopupmenuX = findall(hFigSpecr,'Tag','specr_PopupmenuX');
hPopupmenuY = findall(hFigSpecr,'Tag','specr_PopupmenuY');
settings = getappdata(hFigSpecr,'settings');
file = settings.file;
scan = settings.scan;

% --- check dynamically if there are more scans added to spec file
[fid,message] = fopen(file);
fseek(fid,scan.fidPos(end),'bof');  % move fid to end of the last stored scan
scanline = fgetl(fid);      % skip the currentline (head of the last stored scan);
flagNewScan = 0;
while feof(fid) == 0
    tempfid = ftell(fid);
    scanline = fgetl(fid);
    if length(scanline) >= 3 && strcmp(scanline(1:3),'#S ')
        scan.fidPos = [scan.fidPos,tempfid];
        scan.head{length(scan.fidPos)} = scanline;
        flagNewScan = 1;
    end
end
fclose(fid);
settings.scan = scan;
setappdata(hFigSpecr,'settings',settings);
settings = getappdata(hFigSpecr,'settings');
selection = length(scan.fidPos);
scan.selection = cell(length(selection),1);
[fid,message] = fopen(file);
scan.selectionNumber = [];
try
    for iSelection = 1:length(selection)
        fseek(fid,scan.fidPos(selection(iSelection)),'bof');
        % --- read the scan number      PS: scan number sometimes is not the
        % same of scan index.
        scanline = fgetl(fid);
        while ~strcmp(scanline(1:3),'#S ')
            scanline = fgetl(fid);
        end
        space_pos = findstr(scanline,' ');
        scan.selectionNumber(iSelection) = str2num(scanline(space_pos(1)+1:space_pos(2)-1));
        % --- read time of scan #D
        while ~strcmp(scanline(1:2),'#D')
            scanline = fgetl(fid);
        end
        scan.selection{iSelection}.time = scanline(4:end);
        % --- read number of scan columns #N ...
        while ~strcmp(scanline(1:2),'#N')
            scanline = fgetl(fid);
        end
        scan.selection{iSelection}.length = str2num(scanline(3:end));
        % --- read head of scan columns #L ...
        while ~strcmp(scanline(1:2),'#L')
            scanline = fgetl(fid);
        end
        scanline = scanline(4:end);
        space = findstr(scanline,'  ');
        lengthSpace = length(space);
        for iSpace = lengthSpace:-1:2
            if space(iSpace) == space(iSpace-1)+1
                space(iSpace) = [];
            end
        end
        space = [-1 space length(scanline)+1];
        scan.selection{iSelection}.colHead = ...
            cell(1,scan.selection{iSelection}.length);
        for iCol = 1:scan.selection{iSelection}.length
            colHead = scanline(space(iCol)+2:space(iCol+1)-1);
            while colHead(1) == ' '
                colHead(1) = '';
            end
            scan.selection{iSelection}.colHead{iCol} = colHead;
        end

        % --- read scan data
        colData = [];
        str_scanline = num2str(scanline);
        while ~strcmp(str_scanline,'') & ~strcmp(str_scanline,'-1')
            fidPos = ftell(fid);
            scanline = fgetl(fid);
            str_scanline = num2str(scanline);
            while ~strcmp(str_scanline,'') & ~strcmp(str_scanline,'-1')...
                    & ~strcmp(str_scanline(1:1),'#')
                fseek(fid,fidPos,'bof');
                colData = [colData fscanf(fid,'%g',[scan.selection{iSelection}.length,1])];
                scanline = fgetl(fid);
                fidPos = ftell(fid);
                scanline = fgetl(fid);
                str_scanline = num2str(scanline);
            end
        end
        scan.selection{iSelection}.colData = colData';
    end
catch
    return;
end
fclose(fid);
scan.selectionIndex = selection;        % store the selected scan index
settings.scan = scan;
setappdata(hFigSpecr,'settings',settings);
settings = getappdata(hFigSpecr,'settings');
if get(hTimerMonitor,'TasksExecuted') == 1 | flagNewScan == 1;
    set(hPopupmenuX,...
        'String',scan.selection{1}.colHead,...
        'Value',1);
    set(hPopupmenuY,...
        'String',scan.selection{1}.colHead,...
        'Value',scan.selection{1}.length);
end
try
    scanplot;
catch
end

%================================================================
% --- start callback function of monitor timer
%================================================================
function timerMonitorStartFcn(hObject,eventdata,hEnableGroup,initEnable)
hFigSpecr = findall(0,'Tag','specr_Fig');
resettoolbar(hFigSpecr);
set(hEnableGroup,'Enable','off');


%================================================================
% --- stop callback function of monitor timer
%================================================================
function timerMonitorStopFcn(hObject,eventdata,hEnableGroup,initEnable)
for i=1:length(hEnableGroup)
    set(hEnableGroup(i),'Enable',initEnable{i});
end

