function scanplot(varargin)
% SCANPLOT Called by specr to plot scans.
%
% Copyright 2004, Zhang Jiang

hFigSpecr = findall(0,'Tag','specr_Fig');
hPopupmenuX = findall(hFigSpecr,'Tag','specr_PopupmenuX');
hPopupmenuY = findall(hFigSpecr,'Tag','specr_PopupmenuY');
hPopupmenuPlotStyle = findall(hFigSpecr,'Tag','specr_PopupmenuPlotStyle');
hAxes = findall(hFigSpecr,'Tag','specr_Axes');
settings = getappdata(hFigSpecr,'settings');

file = settings.file;
scan = settings.scan;

if isempty(file) | isempty(scan) | ~isfield(scan,'selection') | isempty(scan.selection{1})
    return;
end

% --- set x, y axis labels
popupmenuXString = get(hPopupmenuX,'String');
popupmenuYString = get(hPopupmenuY,'String');
popupmenuXValue = get(hPopupmenuX,'Value');
popupmenuYValue = get(hPopupmenuY,'Value');
set(get(hAxes,'XLabel'),'String',popupmenuXString(popupmenuXValue));
set(get(hAxes,'YLabel'),'String',popupmenuYString(popupmenuYValue));

cla(hAxes);
hLine = [];
for iSelection = 1:length(scan.selection)
    % --- if ydata has negative data,then ydataError = 0
    if isempty(find( scan.selection{iSelection}.colData(:,popupmenuYValue)<0 ))
        % --- statistical error
        ydataError = ...
            sqrt(scan.selection{iSelection}.colData(:,popupmenuYValue));
    else
        ydataError = ...
            zeros(length(scan.selection{iSelection}.colData(:,popupmenuYValue)),1);
    end

    hLine(iSelection) = line('Parent',hAxes,...
        'XData',scan.selection{iSelection}.colData(:,popupmenuXValue),...
        'YData',scan.selection{iSelection}.colData(:,popupmenuYValue),...
        'Tag',['specrScan',num2str(scan.selectionNumber(iSelection))]);
    setappdata(hLine(iSelection),'ydataError',ydataError);
end
set(hLine,...
    'Color','b',...
    'LineStyle','-',...
    'Marker','o',...
    'MarkerSize',3,...
    'MarkerFaceColor','m');


% --- set title
[filepath,filename,fileext,fileversn] = fileparts(file);
title_str = {...
    ['File: ',titlestr(filename),',   Scan ',num2str(scan.selectionNumber),',   ',scan.selection{1}.time];...
    [scan.head{scan.selectionIndex(1)}(length(num2str(scan.selectionNumber(1)))+5:end)]...
    };
set(get(hAxes,'Title'),'String',title_str);


%--- calculate Peak, COM, and FWHM and label plot
[scanPeak,scanCOM,scanFWHM] = params(...
    scan.selection{1}.colData(:,[popupmenuXValue,popupmenuYValue]));
xlabelStr = {scan.selection{1}.colHead{get(hPopupmenuX,'Value')};...
    '   ';...
    ['Peak ',num2str(scanPeak.Y),' @ ',num2str(scanPeak.X),...
    ',   COM ',num2str(scanCOM),...
    ',   FWHM ',num2str(scanFWHM.FWHM),' @ ',num2str(scanFWHM.center)]};
set(get(hAxes,'XLabel'),'String',xlabelStr);

% --- determine legend
curvelegend(hFigSpecr);
%assignin('base','hAxes',hAxes);
