function sresult = specr(varargin)
% SPECR Program to read spec files
% 
% Copyright 2004 Zhang Jiang
% $Revision: 3.3 $  $Date: 2004/11/23 $
% $Revision: 3.4 $  $Date: 2005/12/28 $

hFigSpecr = findall(0,'Tag','specr_Fig');
if isempty(hFigSpecr)
    initFigure;
else
    figure(hFigSpecr);
    return;
end

% --- turn off waring;
warning off MATLAB:Axes:NegativeDataInLogAxis;


%================================================================
% --- initialize figure layout
%================================================================
function initFigure
% --------------------------------
% --- main figure handle
% --------------------------------
posScreen   = get(0,'screenSize');
hFigWidth   = 680;
hFigHeight  = 531;
hFigPos     = [...
    posScreen(3)/2-hFigWidth/2,...
    posScreen(4)/2-hFigHeight/2,...
    hFigWidth,hFigHeight];
hFigSpecr = figure(...
    'BackingStore','on',...
    'Units','pixels',...
    'DockControls','off',...
    'Resize','on',...
    'ResizeFcn',@specr_ResizeFcn,...
    'PaperOrient','portrait',...
    'PaperPositionMode','auto',...
    'IntegerHandle','off',...
    'NumberTitle','off',...
    'MenuBar','none',...
    'Toolbar','none',...
    'Name','Spec Reader',...
    'Position',hFigPos,...
    'HandleVisibility','callback',...
    'Tag','specr_Fig',...
    'CreateFcn',@specr_CreateFcn,...
    'CloseRequestFcn',@specr_CloseRequestFcn,...
    'UserData',[]);


% --------------------------------
% --- axes handle
% --------------------------------
hAxes = axes(...
    'Parent',hFigSpecr,...
    'Box','on',...
    'XGrid','on',...
    'YGrid','on',...
    'Tag','specr_Axes');

% --------------------------------
% --- file menu handles
% --------------------------------
hMenuFile = uimenu(hFigSpecr,...
    'Label','&File',...
    'Position',1,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFile');
hMenuFileOpen = uimenu(hMenuFile,...
    'Label','&Open Spec File...',...
    'Position',1,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFileOpen',...
    'Accelerator','O',...
    'callback',@openspec);
hMenuFileClose = uimenu(hMenuFile,...
    'Label','&Close',...
    'Position',2,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFileClose',...
    'Accelerator','W',...
    'callback',@specr_CloseRequestFcn);
hMenuFileSave = uimenu(hMenuFile,...
    'Label','&Save',...
    'Position',3,...
    'Separator','on',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFileSave',...
    'Accelerator','S',...
    'callback','curvesave');
hMenuFileSave2Workspace = uimenu(hMenuFile,...
    'Label','Save to &Workspace',...
    'Position',4,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFileSave2Workspace',...
    'callback','save2workspace');
hMenuFilePreferences = uimenu(hMenuFile,...
    'Label','Pre&ferences...',...
    'Position',5,...
    'Separator','on',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFilePreferences',...
    'callback','preferences');
hMenuFilePageSetup = uimenu(hMenuFile,...
    'Label','Pa&ge Setup...',...
    'Position',6,...
    'Separator','on',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFilePageSetup',...
    'callback','pagesetupdlg');
hMenuFilePrintPreview = uimenu(hMenuFile,...
    'Label','Print Pre&view...',...
    'Position',7,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFilePrintPreview',...
    'callback',@specr_PrintPreviewFcn);
hMenuFilePrint = uimenu(hMenuFile,...
    'Label','&Print...',...
    'Position',8,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFilePrint',...
    'Accelerator','P',...
    'callback',@specr_PrintFcn);
hMenuFilePrintToFigure = uimenu(hMenuFile,...
    'Label','Print to Figure...',...
    'Position',9,...
    'Accelerator','G',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuFilePrintToFigure',...
    'callback','print2figure');

% --------------------------------
% --- tools menu handles
% --------------------------------
hMenuTools = uimenu(hFigSpecr,...
    'Label','&Tools',...
    'Position',2,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuTools');
hMenuToolsShowScan = uimenu(hMenuTools,...
    'Label','Sho&w Current Scan',...
    'Callback','showscan',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuToolsShowScan');
hMenuToolsInvertX = uimenu(hMenuTools,...
    'Label','&Invert X Axis',...
    'Callback','invertxaxis',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuToolsInvertX');
hMenuToolsFoldX = uimenu(hMenuTools,...
    'Label','Fold X &Axis (New Figure) ...',...
    'Callback','foldxaxis',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuToolsFoldX');
hMenuToolsSubBKG = uimenu(hMenuTools,...
    'Label','Subtract Constant &Background',...
    'Callback','subtractbkg',...
    'separator','on',...
    'HandleVisibility','callback',...
    'Accelerator','B',...    
    'Tag','specr_MenuToolsISubBKG');
hMenuToolsScanMerge = uimenu(hMenuTools,...
    'Label','&Merge Scans',...
    'HandleVisibility','callback',...
    'Accelerator','M',...
    'Callback','scanmerge');
hMenuToolsConvert = uimenu(hMenuTools,...
    'Label','&Convert 2Theta to Qz (For Reflectivity and Longitudinal Diffuse)',...
    'Callback','convert2theta2qz',...
    'HandleVisibility','callback',...
    'Accelerator','T',...
    'Tag','specr_MenuToolsConvert');
hMenuToolsFootprint = uimenu(hMenuTools,...
    'Label','&Footprint Correction (For Reflectivity in Qz Only)',...
    'Callback','footprint',...
    'HandleVisibility','callback',...
    'Tag','specr_MenuToolsFootprint');
hMenuToolsNormalize = uimenu(hMenuTools,...
    'Label','&Normalize...',...
    'HandleVisibility','callback',...
    'Callback','curvenormalize');
hMenuToolsRocking = uimenu(hMenuTools,...
    'Label','&Geometric Correction for Rocking Scan (hscan) ...',...
    'HandleVisibility','callback',...
    'Callback','georocking');
hMenuToolsEngwav = uimenu(hMenuTools,...
    'Label','Calculate &Energy/Wavelength...',...
    'Separator','on',...
    'HandleVisibility','callback',...
    'Callback','engwav');
hMenuToolsTrueRef = uimenu(hMenuTools,...
    'Label','&True Reflectivity...',...
    'HandleVisibility','callback',...
    'Callback','trueref');
hMenuToolsSettings = uimenu(hMenuTools,...
    'Label','&Settings...',...
    'Separator','on',...
    'HandleVisibility','callback',...
    'Callback','specrsettings');
    
% --------------------------------
% --- help menu handles
% --------------------------------
hMenuHelp = uimenu(hFigSpecr,...
    'Label','&Help',...
    'Position',3,...
    'HandleVisibility','callback',...
    'Tag','specr_MenuHelp');    
hMenuHelpSpecr = uimenu(hMenuHelp,...
    'Label','&Spec Reader Help',...
    'HandleVisibility','callback',...
    'Callback',@specr_Help);
hMenuHelpAbout = uimenu(hMenuHelp,...
    'Label','&About Spec Reader',...
    'HandleVisibility','callback',...
    'Separator','on',...
    'Callback',@specr_AboutSpecr);
    
% --------------------------------
% --- toolbar handles
% --------------------------------
icons = load('icons.mat');
hToolbar = uitoolbar(hFigSpecr,...
    'Tag','specr_Toolbar');
hToolbarOpen = uipushtool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','opendoc.mat')),...
    'TooltipString','Open Spec File',...
    'ClickedCallback',@openspec,...
    'Tag','toolbarOpen');
hToolbarSave = uipushtool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','savedoc.mat')),...
    'TooltipString','Save Data',...
    'ClickedCallback','curvesave',...
    'Tag','toolbarSave');
hToolbarPrint = uipushtool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','printdoc.mat')),...
    'TooltipString','Print Figure',...
    'ClickedCallback',@specr_PrintFcn,...
    'Tag','toolbarPrint');
hToolbarEditPlot = uitoggletool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','pointer.mat')),...
    'TooltipString','Edit Plot',...
    'ClickedCallback',@toolbarEditPlotFcn,...
    'Separator','on',...
    'Tag','toolbarEditPlot');
iconToolbarZoom = load(...
    fullfile(matlabroot,'toolbox','matlab','icons','zoom.mat'));
hToolbarZoom = uitoggletool(hToolbar,...
    'CDATA',iconToolbarZoom.zoomCData,...
    'TooltipString','Zoom',...
    'Separator','on',...
    'State','off',...
    'ClickedCallback',@toolbarZoomFcn,...
    'Tag','toolbarZoom');
hToolbarPan = uitoggletool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','pan.mat')),...
    'TooltipString','Pan',...
    'ClickedCallback',@toolbarPanFcn,...
    'Tag','toolbarPan');
hToolbarDataCursor = uitoggletool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','datatip.mat')),...
    'TooltipString','Data Cursor',...
    'ClickedCallback',@toolbarDataCursorFcn,...
    'Separator','on',...
    'Tag','toolbarDataCursor');
hToolbarLegend = uitoggletool(hToolbar,...
    load(fullfile(matlabroot,'toolbox','matlab','icons','legend.mat')),...
    'TooltipString','Legend On/Off',...
    'ClickedCallback',@toolbarLegendFcn',...
    'Separator','on',...
    'Tag','toolbarLegend');
hToolbarGrid = uitoggletool(hToolbar,...
    'CData',icons.icongrid,...
    'TooltipString','Grid On/Off',...
    'ClickedCallback','grid',...
    'State','on',...
    'Tag','toolbarGrid');
iconPlottoolsOff = load(...
    fullfile(matlabroot,'toolbox','matlab','icons','plottoolsoff.mat'));
hToolbarPlottoolsOff = uipushtool(hToolbar,...
    'CData',iconPlottoolsOff.cdata,...
    'TooltipString','Hide Plot Tools',...
    'ClickedCallback',@toolbarPlottoolsOffFcn,...
    'Separator','on',...
    'Enable','off',...
    'Tag','toolbarPlottoolsOff');
iconPlottoolsOn = load(...
    fullfile(matlabroot,'toolbox','matlab','icons','plottoolson.mat'));
hToolbarPlottoolsOn = uipushtool(hToolbar,...
    'CData',iconPlottoolsOn.cdata,...
    'TooltipString','Show Plot Tools',...
    'ClickedCallback',@toolbarPlottoolsOnFcn,...
    'Enable','on',...
    'Tag','toolbarPlottoolsOn');
hToolbarMonitor = uitoggletool(hToolbar,...
    'CData',icons.iconmonitor.play,...
    'TooltipString','Scan Monitor On/Off',...
    'Separator','on',...
    'ClickedCallback','monitorscan',...
    'State','off',...
    'Tag','toolbarMonitor');
hToolbarInvert = uipushtool(hToolbar,...
    'CData',icons.iconinvertx,...
    'Separator','on',...    
    'TooltipString','Invert X Axis',...
    'ClickedCallback','invertxaxis',...
    'Tag','toolbarInvert');
hToolbarFold = uipushtool(hToolbar,...
    'CData',icons.iconfoldx,...
    'TooltipString','Fold X Axis',...
    'ClickedCallback','foldxaxis',...
    'Tag','toolbarFold');
hToolbarMerge = uipushtool(hToolbar,...
    'CData',icons.iconmerge,...
    'Separator','on',...  
    'TooltipString','Merge Scans',...
    'ClickedCallback','scanmerge',...
    'Tag','toolbarMerge');
hToolbarConvert = uipushtool(hToolbar,...
    'CData',icons.iconconvert,...
    'TooltipString','Convert 2Theta to Qz (For Reflectivity and Longitudinal Diffuse)',...
    'ClickedCallback','convert2theta2qz',...
    'Tag','toolbarConvert');
hToolbarFootprint = uipushtool(hToolbar,...
    'CData',icons.iconfootprint,...
    'TooltipString','Footprint Correction (For Reflectivity in Qz Space Only)',...
    'ClickedCallback','footprint',...
    'Tag','toolbarFootprint');
hToolbarGeorocking = uipushtool(hToolbar,...
    'CData',icons.iconrocking,...
    'TooltipString','Geometric Correction For Rocking Scan (hscan Only)',...
    'ClickedCallback','georocking',...
    'Tag','toolbarGeorocking');
hToolbarSettings = uipushtool(hToolbar,...
    'CData',icons.iconsettings,...
    'Separator','on',...    
    'TooltipString','Settings',...
    'ClickedCallback','specrsettings',...
    'Tag','toolbarSettings');

% --------------------------------
% --- pushbotton handles
% --------------------------------
hPushbuttonSelectScan = uicontrol(hFigSpecr,...
    'Style','pushbutton',...
    'String','Select Scan',...
    'TooltipString',' Select Scan',...
    'Tag','specr_PushbuttonSelectScan',...
    'callback',@selectscan);
hPushbuttonRefresh = uicontrol(hFigSpecr,...
    'Style','pushbutton',...
    'String','Replot',...
    'TooltipString',' Replot',...
    'Tag','specr_PushbuttonRefresh',...
    'callback','refreshscanplot');

% --------------------------------
% --- popupmenu handles
% --------------------------------
hPopupmenuX = uicontrol(hFigSpecr,...
    'Style','popupmenu',...
    'Background','w',...
    'String','X Axis',...
    'TooltipString',' Select X Axis',...
    'Tag','specr_PopupmenuX',...
    'callback',@scanplot);
hPopupmenuY = uicontrol(hFigSpecr,...
    'Style','popupmenu',...
    'Background','w',...
    'String','Y Axis',...
    'TooltipString',' Select Y Axis',...
    'Tag','specr_PopupmenuY',...
    'callback',@scanplot);
hPopupmenuPlotStyle = uicontrol(hFigSpecr,...
    'Style','popupmenu',...
    'Background','w',...
    'String',{'linear','logx','logy','logxy'},...
    'TooltipString',' Plot Style',...
    'Tag','specr_PopupmenuPlotStyle',...
    'callback',@plotstyle);


%================================================================
% --- things to do when starting specr:
% 1. initalize the settings; save to application data 'settings'
%================================================================
function specr_CreateFcn(hObject,eventdata)
hFigSpecr = hObject;
settings.wavelength = 1.686859478480;
settings.footprintAngle     = 0.5;              % incident side footprint angle
settings.footprintAngleSC   = 0.5;              % detector side footprint angle
settings.georockingSCFlag   = 0;                % 0) no detector side correction 1) yes
settings.qz4Rocking         = 0.15;             % default qz for rocking scan
settings.merge.mode  = 2;        % 1) intensity based 2) # of points based (default) 
settings.merge.interpMethod = 1; % 1) spline (default) 2) linear 3) nearest 4) cubic
settings.monitorPeriod   = 0.5;  % scan monitor period (sec)
settings.file       = '';
settings.scan       = '';
settings.savepath   = '';
settings.trueref.openfiles = {};
settings.trueref.openpath = '';
setappdata(hFigSpecr,'settings',settings);


%================================================================
% --- specr figure close request function
%================================================================
function specr_CloseRequestFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hFigShowScan = findall(0,'Tag','figSpecrShowScan');
hFigTrueref = findall(0,'Tag','trueref_Fig');
hPopupmenuX = findall(hFigSpecr,'Tag','specr_PopupmenuX');
hPopupmenuY = findall(hFigSpecr,'Tag','specr_PopupmenuY');
hPopupmenuPlotStyle = findall(hFigSpecr,'Tag','specr_PopupmenuPlotStyle');
hAxes = findall(hFigSpecr,'Tag','specr_Axes');
hTimerMonitor   = timerfindall('Tag','timerMonitor');
settings = getappdata(hFigSpecr,'settings');
file = settings.file;
scan = settings.scan;
% --- if no plot, then close without request
if ~isempty(file) & ~isempty(scan) & isfield(scan,'selection') & ~isempty(scan.selection{1})
    quitButton = questdlg('Quit without saving data ?',...
        'Spec Reader - Confirm Close','Quit','Cancel','Cancel');
    switch quitButton
        case 'Cancel'
            % take no action
            return;
        case 'Quit'
    end
end
resetfigspecr;
warning on MATLAB:Axes:NegativeDataInLogAxis;
if ~isempty(hFigTrueref)
    delete(hFigTrueref);
end
if ~isempty(hFigShowScan)
    delete(hFigShowScan);
end
delete(hFigSpecr);
return;


%================================================================
% --- specr figure resize function
%================================================================
function specr_ResizeFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hAxes = findall(hFigSpecr,'Tag','specr_Axes');
hPushbuttonSelectScan = findall(hFigSpecr,'Tag','specr_PushbuttonSelectScan');
hPushbuttonRefresh = findall(hFigSpecr,'Tag','specr_PushbuttonRefresh');
hPopupmenuX = findall(hFigSpecr,'Tag','specr_PopupmenuX');
hPopupmenuY = findall(hFigSpecr,'Tag','specr_PopupmenuY');
hPopupmenuPlotStyle = findall(hFigSpecr,'Tag','specr_PopupmenuPlotStyle');
figureSize = get(hFigSpecr,'Position');
PosFigureTopCenter = [(figureSize(3))/2,figureSize(4)-35];
try         % in case figure size is too samll that width and height < 0
    set(hPushbuttonSelectScan,...
        'Units','Pixels',...
        'Position',[PosFigureTopCenter(1)-220,PosFigureTopCenter(2),80,25]);
    set(hPushbuttonRefresh,...
        'Units','Pixels',...
        'Position',[PosFigureTopCenter(1)+140,PosFigureTopCenter(2),80,25]);
    set(hPopupmenuX,...
        'Units','Pixels',...
        'Position',[PosFigureTopCenter(1)-130,PosFigureTopCenter(2),80,25]);
    set(hPopupmenuY,...
        'Units','Pixels',...
        'Position',[PosFigureTopCenter(1)-40,PosFigureTopCenter(2),80,25]);
    set(hPopupmenuPlotStyle,...
        'Units','Pixels',...
        'Position',[PosFigureTopCenter(1)+50,PosFigureTopCenter(2),80,25]);
    set(hAxes,...
        'Units','Pixels',...
        'Position',[65,80,figureSize(3)-130,figureSize(4)-160]);
catch
end

%================================================================
% --- print preview callback function
%================================================================
function specr_PrintPreviewFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hHide = [findall(hFigSpecr,'Style','pushbutton');...
         findall(hFigSpecr,'Style','popupmenu')];
%set(hHide,'Visible','off');
hPrintPreview = printpreview(hFigSpecr);
%set(hHide,'Visible','on');


%================================================================
% --- print callback function
%================================================================
function specr_PrintFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hHide = [findall(hFigSpecr,'Style','pushbutton');...
         findall(hFigSpecr,'Style','popupmenu')];
set(hHide,'Visible','off');
printdlg;
set(hHide,'Visible','on');


%================================================================
% --- toolbar plottools off callback function
%================================================================
function toolbarPlottoolsOffFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarPlottoolsOff = findall(hFigSpecr,'Tag','toolbarPlottoolsOff');
hToolbarPlottoolsOn  = findall(hFigSpecr,'Tag','toolbarPlottoolsOn');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
if strcmp(get(hToolbarPlottoolsOff,'Enable'),'off')
    return;
else
    zoom off;
    pan off;
    datacursormode off;
    set(hToolbarZoom,'State','off');
    set(hToolbarPan,'State','off');
    set(hToolbarDataCursor,'State','off');
    set(hToolbarPlottoolsOff,'Enable','off');
    set(hToolbarPlottoolsOn,'Enable','on');
    plottools off;
end


%================================================================
% --- toobar plottools on callback function
%================================================================
function toolbarPlottoolsOnFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarPlottoolsOff = findall(hFigSpecr,'Tag','toolbarPlottoolsOff');
hToolbarPlottoolsOn  = findall(hFigSpecr,'Tag','toolbarPlottoolsOn');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
if strcmp(get(hToolbarPlottoolsOn,'Enable'),'off')
    return;
else
    plotedit;
    zoom off;
    pan off;
    datacursormode off;
    set(hToolbarEditPlot,'State','on');
    set(hToolbarZoom,'State','off');
    set(hToolbarPan,'State','off');
    set(hToolbarDataCursor,'State','off');
    set(hToolbarPlottoolsOn,'Enable','off');
    set(hToolbarPlottoolsOff,'Enable','on');
    plottools on;
end


%================================================================
% --- toolbar edit plot callback
%================================================================
function toolbarEditPlotFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
plotedit;
zoom off;
pan off;
datacursormode off;
set(hToolbarZoom,'state','off');
set(hToolbarPan,'state','off');
set(hToolbarDataCursor,'state','off');

%================================================================
% --- toolbar zoom callback
%================================================================
function toolbarZoomFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
plotedit off;
zoom;
pan off;
datacursormode off;
set(hToolbarEditPlot,'state','off');
set(hToolbarPan,'state','off');
set(hToolbarDataCursor,'state','off');

%================================================================
% --- toolbar pan callback
%================================================================
function toolbarPanFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
plotedit off;
zoom off;
pan;
datacursormode off;
set(hToolbarEditPlot,'state','off');
set(hToolbarZoom,'state','off');
set(hToolbarDataCursor,'state','off');


%================================================================
% --- toolbar datacuror callback
%================================================================
function toolbarDataCursorFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
hToolbarEditPlot = findall(hFigSpecr,'Tag','toolbarEditPlot');
hToolbarZoom = findall(hFigSpecr,'Tag','toolbarZoom');
hToolbarPan = findall(hFigSpecr,'Tag','toolbarPan');
hToolbarDataCursor = findall(hFigSpecr,'Tag','toolbarDataCursor');
plotedit off;
zoom off;
pan off;
try
    datacursormode;
catch
end
set(hToolbarEditPlot,'state','off');
set(hToolbarZoom,'state','off');
set(hToolbarPan,'state','off');


%================================================================
% --- toolbar legend callback funcion
%================================================================
function toolbarLegendFcn(hObject,eventdata)
hFigSpecr = findall(0,'Tag','specr_Fig');
curvelegend(hFigSpecr);


%================================================================
% --- menu specr help callback fcn
%================================================================
function specr_Help(hObject,eventdata)
%helpWeb = fullfile(matlabroot,'toolbox','xraylabtool','help','xraylabtool_page.html');
%helpview(helpWeb);
msgbox('No help!','Help on Spec Reader','Help','modal');
 

%================================================================
% --- menu aboutspecr function callback
%================================================================
function specr_AboutSpecr(hObject,eventdata)
text_string = {...
    'Spec Reader 3.5 (2006-06-15)';...
    ' ';...
    'X-Ray and Soft Condensed Matter Group';...
    'Department of Physics';...
    'University of California, San Diego';...
    'Copyright 2004-2006 Zhang Jiang';...
    'Email: zjiang@physics.ucsd.edu'};
icons = load('icons.mat');
msgbox(text_string,'About Spec Reader','custom',icons.logo.cdata,icons.logo.colormap,'modal');
